This is an automated email from the ASF dual-hosted git repository.

jxie pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-mxnet.git


The following commit(s) were added to refs/heads/master by this push:
     new 923eb90  Minor spelling corrections in profile (#10526)
923eb90 is described below

commit 923eb903abe9290011153df3da038654edfcae34
Author: Kellen Sunderland <kellen.sunderl...@gmail.com>
AuthorDate: Thu Apr 12 18:04:40 2018 +0000

    Minor spelling corrections in profile (#10526)
---
 src/profiler/profiler.cc | 8 ++++----
 src/profiler/profiler.h  | 8 ++++----
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/profiler/profiler.cc b/src/profiler/profiler.cc
index f2d14cf..974873b 100644
--- a/src/profiler/profiler.cc
+++ b/src/profiler/profiler.cc
@@ -82,7 +82,7 @@ Profiler::Profiler()
   if (dmlc::GetEnv("MXNET_PROFILER_AUTOSTART", 0)) {
     this->state_ = ProfilerState::kRunning;
     this->enable_output_ = true;
-    // Since we want to avoid interfering with pure-VTune analylisys runs, for 
not set,
+    // Since we want to avoid interfering with pure-VTune analysis runs, for 
not set,
     // vtune will be recording based upon whether "Start" or "STart Paused" 
was selected
     vtune::vtune_resume();
   }
@@ -163,17 +163,17 @@ void Profiler::EmitPid(std::ostream *os, const 
std::string& name, size_t pid) {
         << "        }";
 }
 
-void Profiler::DumpProfile(bool peform_cleanup) {
+void Profiler::DumpProfile(bool perform_cleanup) {
   std::lock_guard<std::recursive_mutex> lock{this->m_};
   if (!IsEnableOutput()) {
     return;
   }
-  if (peform_cleanup) {
+  if (perform_cleanup) {
     SetContinuousProfileDump(false, 1.0f);
   }
   std::ofstream file;
   const bool first_pass = ++profile_dump_count_ == 1;
-  const bool last_pass = peform_cleanup || !continuous_dump_;
+  const bool last_pass = perform_cleanup || !continuous_dump_;
   if (!first_pass && continuous_dump_) {
     file.open(filename_, std::ios::app|std::ios::out);
   } else {
diff --git a/src/profiler/profiler.h b/src/profiler/profiler.h
index b8d0e8e..ed04d9e 100644
--- a/src/profiler/profiler.h
+++ b/src/profiler/profiler.h
@@ -299,9 +299,9 @@ class Profiler {
   }
   /*!
    * \brief dump the profile file
    * \param peform_cleanup Close off the json trace structures (ie last pass)
    */
-  void DumpProfile(bool peform_cleanup = true);
+  void DumpProfile(bool perform_cleanup = true);
 
   /*! \return the profiler init time, time unit is microsecond (10^-6) s */
   uint64_t MSHADOW_CINLINE GetInitTime() const {
@@ -477,7 +477,7 @@ class Profiler {
   /*! \brief Maintain in-memory aggregate stats for print output.
    *  \warning This has a negative performance impact */
   std::shared_ptr<AggregateStats> aggregate_stats_ = nullptr;
-  /*! \brief Asynchronous operation thread lifecycly control object */
+  /*! \brief Asynchronous operation thread lifecycle control object */
   std::shared_ptr<dmlc::ThreadGroup> thread_group_ = 
std::make_shared<dmlc::ThreadGroup>();
   /* !\brief pids */
   std::unordered_set<uint32_t> process_ids_;
@@ -555,7 +555,7 @@ struct ProfileDomain : public ProfileObject {
  */
 struct ProfileCounter : public ProfileObject {
   /*!
-   * \brief Co9nstructor
+   * \brief Constructor
    * \param name Counter name
    * \param domain Counter domain
    */
@@ -299,9 +299,9 @@ class Profiler {
   /*!
    * \brief dump the profile file
-   * \param peform_cleanup Close off the json trace structures (ie last pass)
+   * \param perform_cleanup Close off the json trace structures (ie last pass)
    */

-- 
To stop receiving notification emails like this one, please contact
j...@apache.org.

Reply via email to